( cd usr/lib ; rm -rf libgdbm.so )
( cd usr/lib ; ln -sf libgdbm.so.2.0.0 libgdbm.so )
( cd usr/lib ; rm -rf libgdbm.so.2 )
( cd usr/lib ; ln -sf libgdbm.so.2.0.0 libgdbm.so.2 )
# Install the info files for this package
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info /usr/info/gdbm.info.gz 2>/dev/null
fi

